package edu.princeton.swing.text;

/**
 * A HighlightedDocumentRenderer is an interface which describes a class which can recieve special
 * read privileges to the protected data of a HighlightedDocument.
 *
 * @version 7.1
 * @author btsang
 */
public interface HighlightedDocumentRenderer
{
    /**
     * When the doRender method of HighlightedDocument is called, it obtains a read lock and passes
     * its protected data to the specified instance of HighlightedDocumentRenderer.  The
     * implementation of HighlightedDocumentRenderer should not modify the data or presume that it
     * will be valid after the method returns.
     *
     * @param chars The characters in the document.
     * @param charStyles The style index of each character in the document.
     * @param charCount The number of characters in the document.
     * @param lineOffsets The offsets of the first character of each line.
     * @param lineCount The number of lines in the document.
     * @param extraInfo An object to hold additional parameters from the caller of allowRender.
     * @see HighlightedDocument#allowRender(HighlightedDocumentRenderer, Object)
     */
    public abstract void doRender(char chars[], byte charStyles[], int charCount,
                                  short lineOffsets[], int lineCount, Object extraInfo);
}
